@@ -12,7 +12,7 @@ from . import core
 
 show_default_optimize_code_points = core.show_default_optimize_code_points
 
-__version__ = '0.6.3'
+__version__ = '0.6.5'
 __doc__ = """
 VFB2UFO3
 DESCRIPTION
@@ -40,32 +40,32 @@ to your FontLab Macros folder as shown:
 
 ```
 [user folder]
-  `-- Documents
-      `-- Fontlab
-          `-- Studio 5
-              `-- Macros
-                  `-- System
-                      `-- Modules
-                          `-- vfb2ufo3
-                              `-- __init__.py
-                              `-- core.pyd
-                              `-- designspace.pyd
-                              `-- fdk.pyd
-                              `-- fea.pyd
-                              `-- fontinfo.pyd
-                              `-- glif.pyd
-                              `-- groups.pyd
-                              `-- kern.pyd
-                              `-- mark.pyd
-                              `-- plist.pyd
-                              `-- tools.pyd
-                              `-- user.py
-                              `-- vfb.pyd
-                            `-- dlls
-                                `-- libgcc_s_dw2-1.dll
-                                `-- libgomp-1.dll
-                                `-- libstdc++-6.dll
-                                `-- libwinpthread-1.dll
+  └── Documents
+      └── Fontlab
+          └── Studio 5
+              └── Macros
+                  └── System
+                      └── Modules
+                          └── vfb2ufo3
+                              ├── dlls
+                              │   ├── libgcc_s_dw2-1.dll
+                              │   ├── libgomp-1.dll
+                              │   ├── libstdc++-6.dll
+                              │   └── libwinpthread-1.dll
+                              ├── __init__.py
+                              ├── core.pyd
+                              ├── designspace.pyd
+                              ├── fdk.pyd
+                              ├── fea.pyd
+                              ├── fontinfo.pyd
+                              ├── glif.pyd
+                              ├── groups.pyd
+                              ├── kern.pyd
+                              ├── mark.pyd
+                              ├── plist.pyd
+                              ├── tools.pyd
+                              ├── user.py
+                              └── vfb.pyd
 ```
 
 REQUIREMENTS
@@ -88,6 +88,10 @@ OPTIONAL
   pip install afdko
   https://github.com/adobe-type-tools/afdko
 
+  MinGW 32-bit/i686 GCC 9.3.0
+  http://winlibs.com
+  http://mingw.org
+
 FUNCTIONALITY
 UFO output is produced without changes to the source font. The source font will
 be copied and UFOs will be created from the copy. If the font is multiple
@@ -429,7 +433,7 @@ Recommended naming for FontLab-style kerning groups:
 _public.kern1.A: A' Agrave Aacute Acircumflex Atilde Adieresis Aring...
 _public.kern2.A: A' AE Agrave Aacute Acircumflex Atilde Adieresis Aring...
 
-Final output (UFO group plist):
+Final output (UFO groups.plist):
 <key>public.kern1.A</key>
 <array>
 	<string>A</string>
@@ -628,6 +632,14 @@ The GCC DLLs are covered under the GPL License; all other source is covered
 under the MIT License.
 
 Version history
+version 0.6.5
+change to `glif.hpp`
+
+version 0.6.4
+remove schedule from OpenMP pragma
+correction for quadratic curves in `glif.pyx`
+correction for `glif` file name creation
+
 version 0.6.3
 added 32-bit GCC DLLs
 C++ string formatting improved utilizing {fmt} formatting library
